% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ops.R
\name{ops_snapshot_cols}
\alias{ops_snapshot_cols}
\title{Retrieve column names recorded at a snapshot}
\usage{
ops_snapshot_cols(label, keep = NULL)
}
\arguments{
\item{label}{(character) Snapshot label passed to \code{ops_snapshot()}.}

\item{keep}{(character or NULL) Column names to exclude from the returned
vector (i.e. columns to retain in the data even if they were present at
that snapshot). Default \code{NULL}.}
}
\value{
A character vector of column names.
}
\description{
Returns the column names stored by a previous \code{\link{ops_snapshot}}
call, optionally excluding columns you wish to keep.
}
\examples{
dt <- ops_toy(n = 100)
ops_snapshot(dt, label = "raw")
ops_snapshot_cols("raw")
ops_snapshot_cols("raw", keep = "eid")
}
